@@ -115,6 +115,20 @@ def _get_pyproject_path(start: Path = None) -> Optional[Path]:
     return _find_higher_file("pyproject.toml", start=start)
 
 
+def _get_pyproject_path_from_poetry(pyproject) -> Path:
+    # poetry-core 1.6.0+:
+    recommended = getattr(pyproject, "path", None)
+    # poetry-core <1.6.0:
+    legacy = getattr(pyproject, "file", None)
+
+    if recommended:
+        return recommended
+    elif legacy:
+        return legacy
+    else:
+        raise RuntimeError("Unable to determine pyproject.toml path from Poetry instance")
+
+
 def _get_config(local: Mapping) -> Mapping:
     return _deep_merge_dicts(_default_config(), local)["tool"]["poetry-dynamic-versioning"]
 
@@ -308,7 +322,6 @@ def _get_and_apply_version(
     original: Optional[str] = None,
     pyproject: Optional[Mapping] = None,
     pyproject_path: Optional[Path] = None,
-    cd: bool = False,
     retain: bool = False,
     # fmt: off
     force: bool = False
@@ -337,13 +350,11 @@ def _get_and_apply_version(
 
     initial_dir = Path.cwd()
     target_dir = pyproject_path.parent
-    if cd:
-        os.chdir(str(target_dir))
+    os.chdir(str(target_dir))
     try:
         version = _get_version(config)
     finally:
-        if cd:
-            os.chdir(str(initial_dir))
+        os.chdir(str(initial_dir))
 
     # Condition will always be true, but it makes Mypy happy.
     if name is not None and original is not None:
